@@ -17,11 +17,11 @@ Config::Abstraction - Configuration Abstraction Layer
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 =head1 SYNOPSIS
 
@@ -289,6 +289,10 @@ sub new
 	}
 	$self->_load_config();
 
+	if(my $data = $params->{'data'}) {
+		$self->merge_defaults(defaults => $data) if(scalar keys(%{$data}));
+	}
+
 	if($self->{'config'} && scalar(keys %{$self->{'config'}})) {
 		return $self;
 	}
@@ -603,6 +607,39 @@ sub all
 	return($self->{'config'} && scalar(keys %{$self->{'config'}})) ? $self->{'config'} : undef;
 }
 
+=head2 merge_defaults
+
+Merge the configuration hash into the given hash.
+What's in the object will overwrite what's in the defaults hash.
+
+=cut
+
+sub merge_defaults
+{
+	my $self = shift;
+	my $config = $self->all();
+
+	return $config if(scalar(@_) == 0);
+
+	my $params = Params::Get::get_params('defaults', @_);
+	my $defaults = $params->{'defaults'};
+	return $config if(!defined($defaults));
+	my $section = $params->{'section'};
+
+	if($config->{'global'}) {
+		if($params->{'deep'}) {
+			$defaults = merge($config->{'global'}, $defaults);
+		} else {
+			$defaults = { %{$defaults}, %{$config->{'global'}} };
+		}
+		delete $config->{'global'};
+	}
+	if($section && $config->{$section}) {
+		$config = $config->{$section};
+	}
+	return { %{$defaults}, %{$config} };
+}
+
 # Helper routine to load a driver
 sub _load_driver
 {
